Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PluginConfig ¶
type PluginConfig struct {
VaultAddr string
VaultToken string
Environment string
SpecsPath string
OutputPath string
OutputFormat string
}
PluginConfig contains configuration options received from the environment variables
func Create ¶
func Create() *PluginConfig
Create creates a new object with the actual configuration options
func (*PluginConfig) Validate ¶
func (c *PluginConfig) Validate() error
Validate does a basic validation of values received from the environment
Click to show internal directories.
Click to hide internal directories.